"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.setGradleCrispDependency = exports.setMainConfiguration = exports.setAppDelegateCall = exports.setAppDelegateImport = void 0;
const config_plugins_1 = require("@expo/config-plugins");
const generateCode_1 = require("@expo/config-plugins/build/utils/generateCode");
const withReactNativeCrisp = (expoConfig, { websiteId = 'YOUR_WEBSITE_ID' } = {}) => {
    (0, config_plugins_1.withAppDelegate)(expoConfig, (modConfig) => {
        if (['objc', 'objcpp'].includes(modConfig.modResults.language)) {
            modConfig.modResults.contents = setAppDelegateImport(modConfig.modResults.contents).contents;
            modConfig.modResults.contents = setAppDelegateCall(modConfig.modResults.contents, websiteId).contents;
        }
        return modConfig;
    });
    (0, config_plugins_1.withAppBuildGradle)(expoConfig, (modConfig) => {
        modConfig.modResults.contents = setGradleCrispDependency(modConfig.modResults.contents);
        return modConfig;
    });
    return (0, config_plugins_1.withMainApplication)(expoConfig, (modConfig) => {
        modConfig.modResults.contents = setMainConfiguration(modConfig.modResults.contents, websiteId);
        return modConfig;
    });
};
function setAppDelegateImport(src) {
    return (0, generateCode_1.mergeContents)({
        tag: 'react-native-crisp-chat-sdk',
        src,
        newSrc: '#import <Crisp/Crisp-Swift.h>',
        anchor: /#import "AppDelegate\.h"/,
        offset: 1,
        comment: '//',
    });
}
exports.setAppDelegateImport = setAppDelegateImport;
function setAppDelegateCall(src, websiteId) {
    return (0, generateCode_1.mergeContents)({
        tag: 'react-native-crisp-chat-sdk-call',
        src,
        newSrc: `[CrispSDK configureWithWebsiteID:@"${websiteId}"];`,
        anchor: /- \(BOOL\)application:\(UIApplication \*\)application didFinishLaunchingWithOptions:\(NSDictionary \*\)launchOptions/,
        offset: 2,
        comment: '//',
    });
}
exports.setAppDelegateCall = setAppDelegateCall;
function setMainConfiguration(main, websiteId) {
    const multiDexApp = /public class MainApplication extends MultiDexApplication implements ReactApplication {/g;
    let result = main;
    if (!main.match(multiDexApp)) {
        result = result.replace(/public class MainApplication extends Application implements ReactApplication {/, `import androidx.multidex.MultiDexApplication;

public class MainApplication extends MultiDexApplication implements ReactApplication {
      `);
    }
    const cripsImport = /import im.crisp.client.Crisp;/g;
    if (!main.match(cripsImport)) {
        result = result.replace(/public class MainApplication extends MultiDexApplication implements ReactApplication {/, `import im.crisp.client.Crisp;
      
public class MainApplication extends MultiDexApplication implements ReactApplication {`);
    }
    const cripWebsiteConfig = /Crisp\.configure\(getApplicationContext\(\),"(\w|\d|-)+"\);/g;
    if (!main.match(cripWebsiteConfig)) {
        result = result.replace(/super\.onCreate\(\);/, `super.onCreate();
    Crisp.configure(getApplicationContext(),"${websiteId}");
`);
    }
    return result;
}
exports.setMainConfiguration = setMainConfiguration;
function setGradleCrispDependency(buildGradle) {
    const crispDependency = /implementation 'im.crisp:crisp-sdk:1.0.10'/g;
    let result = buildGradle;
    if (!result.match(crispDependency)) {
        result = result.replace(/dependencies\s?{/, `dependencies {
    implementation 'im.crisp:crisp-sdk:1.0.10'`);
    }
    const multiDex = /implementation 'androidx.multidex:multidex:2.0.1'/g;
    if (!result.match(multiDex)) {
        result = result.replace(/dependencies\s?{/, `dependencies {
    implementation 'androidx.multidex:multidex:2.0.1'`);
    }
    const multiDexConfig = /multiDexEnabled true/g;
    if (!result.match(multiDexConfig)) {
        result = result.replace(/defaultConfig\s?{/, `defaultConfig {
        multiDexEnabled true`);
    }
    return result;
}
exports.setGradleCrispDependency = setGradleCrispDependency;
exports.default = (0, config_plugins_1.createRunOncePlugin)(withReactNativeCrisp, 'react-native-crisp-chat-sdk');
